<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\WooCommerce
 * @copyright   Copyright (c) 2021, WeCodeArt Framework
 * @since 		1.9
 * @version		5.2.2
 */

namespace WeCodeArt\Support\Plugins;

defined( 'ABSPATH' ) || exit;

use WeCodeArt\Core\Content;
use WeCodeArt\Core\Pagination;
use WeCodeArt\Singleton;
use WeCodeArt\Markup;
use WeCodeArt\Markup\SVG;
use WeCodeArt\Customizer;
use WeCodeArt\Integration;
use function WeCodeArt\Functions\get_prop;

/**
 * The Class: Handles all necesary functions and requirements 
 * to ensure proper support for WooCommerce
 */
class WooCommerce implements Integration {

	use Singleton;
	
	/**
	 * Get Conditionals
	 *
	 * @return void
	 */
	public static function get_conditionals() {
		wecodeart( 'conditionals' )->set( [
			'is_woocommerce_active'		=> WooCommerce\Conditional\Plugin::class,
			'is_woocommerce_page'		=> WooCommerce\Conditional\Page::class,
			'is_woocommerce_archive'	=> WooCommerce\Conditional\Archive::class,
		] );

		return [ 'is_woocommerce_active' ];
	}

	/**
	 * Register Hooks
	 *
	 * @return void
	 */
	public function register_hooks() {
		// Add support for WooCommerce 
		add_action( 'after_setup_theme', 	[ $this, 'after_setup_theme' ] );

		// Remove Sidebar
		remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar'	);

		// Content Wrappers
		remove_action( 'woocommerce_before_main_content', 		'woocommerce_output_content_wrapper',		10 );
		add_action( 'woocommerce_before_main_content',    		[ $this, 'before_content_wrapp' ], 	10 );
		remove_action( 'woocommerce_after_main_content',  		'woocommerce_output_content_wrapper_end',	10 );
		add_action( 'woocommerce_after_main_content',    		[ $this, 'after_content_wrapp' ],  	10 );

		// Filters
		add_filter( 'wecodeart/filter/gutenberg/restricted',	[ $this, 'restricted_gutenberg_blocks' ] );
	}

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * @since	unknown
	 */
	public function after_setup_theme() {
		$support = get_prop( wecodeart_config( 'woocommerce' ), 'support', [] );
		// Theme Support
		foreach( $support as $feature => $value ) add_theme_support( $feature, $value );
	}
	
	/**
	 * Before Content - Wraps all WooCommerce content in wrappers which match the theme markup
	 *
	 * @since   3.5
	 * @version 5.2.2
	 *
	 * @return  void
	 */
	public function before_content_wrapp() {
		/**
		 * Added Attributes / can be filtered
		 * @since 3.7.0
		 */		
		?>
		<div <?php echo Markup::generate_attr( 'woocommerce', [
			'class' => 'site-content py-5 wp-block-template-part'
		] ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>>
			<div class="container">
		<?php
	}

	/**
	 * After Content - Wraps all WooCommerce content in wrappers which match the theme markup
	 *
	 * @since   3.5
	 * @version 5.2.2
	 *
	 * @return  void
	 */
	public function after_content_wrapp() {
		?>
			</div>
		</div>
		<!-- /.woocommerce @filter = `wecodeart/filter/wrappers/woocommerce` -->
		<?php
	}

	/**
	 * Filter - Restricted WooCommerce Blocks from theme code
	 *
	 * @since	5.0.0
	 * @version	5.0.0
	 *
	 * @return 	array
	 */
	public function restricted_gutenberg_blocks( $blocks ) {
		return wp_parse_args( [
			'woocommerce/handpicked-products',
			'woocommerce/products-by-attribute',
			'woocommerce/products-by-tag',
			'woocommerce/product-best-sellers',
			'woocommerce/product-top-rated',
			'woocommerce/product-on-sale',
			'woocommerce/product-new',
		], $blocks );
	}
}